# Tendenci

Tendenci is a content management system (CMS) designed for organizations with powerful features for event registration, membership management, and email communication.

Tendenci allows membership management organizations to communicate, manage and conduct transactions with web site visitors. Tendenci is easy to use and offers many modules as one customizable software package.

The name 'Tendenci' was originally created by Randy Sarinas. The original logo, branding, and colors were designed by Aaron Long.

## Installation

For information on how to install Tendenci, follow the instructions in `INSTALL.md`, or [online at Github](https://github.com/tendenci/tendenci-site/blob/master/INSTALL.md).

## Core Developers

We want to recognize some of the developers of the core of Tendenci, from it's beginnings in Microsoft ASP to this current version written in python.

- Ed Schipul
- Jennifer Ulmer
- Donnell Smith
- Nse (Charles) Ekpenyong
- Kathryn Ciaralli
- Adil Ahmed (project manager)
- Jenny Qian
- Eloy Zuniga, Jr.
- Glen Zangirolami
- John-Michael Oswalt (JMO)
- Sam Lee

Tendenci would not exist without them.

Addition thanks to the following people who have contributed to the product as a whole:

- Tim Newton
- David Stagg
- Loren Lugosch
- Nabil Bani
- Sarah Worthy
